[Android] Bootstrap gradle configuration

Jean-Baptiste Kempf git at videolan.org
Fri Feb 6 00:50:21 CET 2015


vlc-ports/android | branch: master | Jean-Baptiste Kempf <jb at videolan.org> | Fri Feb  6 00:50:04 2015 +0100| [bb14a983a3f51f15efe0596a18cf6df8736a258f] | committer: Jean-Baptiste Kempf

Bootstrap gradle configuration

> http://git.videolan.org/gitweb.cgi/vlc-ports/android.git/?a=commit;h=bb14a983a3f51f15efe0596a18cf6df8736a258f
---

 compile-simple.sh |   23 +++++++++++++++++++++--
 1 file changed, 21 insertions(+), 2 deletions(-)

diff --git a/compile-simple.sh b/compile-simple.sh
index d89141d..1eba8f9 100755
--- a/compile-simple.sh
+++ b/compile-simple.sh
@@ -52,8 +52,22 @@ if [ ! -d "gradle/wrapper" ]; then
     rm -rf gradle-${GRADLE_VERSION}-all.zip gradle-${GRADLE_VERSION}
 fi
 
-# Fetch VLC source
-# 1/ libvlc, libvlccore and its plugins
+####################
+# Configure gradle #
+####################
+if [ ! -f gradle.properties ]; then
+    echo keyStoreFile=$HOME/.android/debug.keystore > gradle.properties
+    echo storealias=androiddebugkey >> gradle.properties
+    echo storepwd=android >> gradle.properties
+fi
+if [ ! -f local.properties ]; then
+    echo sdk.dir=$ANDROID_SDK > local.properties
+    echo ndk.dir=$ANDROID_NDK >> local.properties
+fi
+
+####################
+# Fetch VLC source #
+####################
 TESTED_HASH=18e445a
 if [ ! -d "vlc" ]; then
     echo "VLC source not found, cloning"
@@ -82,3 +96,8 @@ if [ "$RELEASE" = 1 ]; then
 fi
 
 ./compile-libvlc.sh $OPTS
+
+##################
+# Compile the UI #
+##################
+./gradlew tasks



More information about the Android mailing list